@@ -43,7 +43,7 @@ IS_OBJECT_MANAGER = True
 class NMState:
     '''Global state
 
-    As per https://developer.gnome.org/NetworkManager/unstable/spec.html#type-NM_STATE
+    As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMState
     '''
     NM_STATE_UNKNOWN = 0
     NM_STATE_ASLEEP = 10
@@ -58,7 +58,7 @@ class NMState:
 class NMConnectivityState:
     '''Connectvity state
 
-    As per https://developer.gnome.org/NetworkManager/unstable/spec.html#type-NM_CONNECTIVITY
+    As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMConnectivityState
     '''
     NM_CONNECTIVITY_UNKNOWN = 0
     NM_CONNECTIVITY_NONE = 1
@@ -70,7 +70,7 @@ class NMConnectivityState:
 class NMActiveConnectionState:
     '''Active connection state
 
-    As per https://developer.gnome.org/NetworkManager/unstable/spec.html#type-NM_ACTIVE_CONNECTION_STATE
+    As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMActiveConnectionState
     '''
     NM_ACTIVE_CONNECTION_STATE_UNKNOWN = 0
     NM_ACTIVE_CONNECTION_STATE_ACTIVATING = 1
@@ -82,7 +82,7 @@ class NMActiveConnectionState:
 class InfrastructureMode:
     '''Infrastructure mode
 
-    As per https://developer.gnome.org/NetworkManager/unstable/spec.html#type-NM_802_11_MODE
+    As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NM80211Mode
     '''
     NM_802_11_MODE_UNKNOWN = 0
     NM_802_11_MODE_ADHOC = 1
@@ -100,7 +100,7 @@ class InfrastructureMode:
 class DeviceState:
     '''Device states
 
-    As per https://developer.gnome.org/NetworkManager/unstable/spec.html#type-NM_DEVICE_STATE
+    As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMDeviceState
     '''
     UNKNOWN = 0
     UNMANAGED = 10
@@ -120,7 +120,7 @@ class DeviceState:
 class NM80211ApSecurityFlags:
     '''Security flags
 
-    As per https://developer.gnome.org/NetworkManager/unstable/spec.html#type-NM_802_11_AP_SEC
+    As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NM80211ApSecurityFlags
     '''
     NM_802_11_AP_SEC_NONE = 0x00000000
     NM_802_11_AP_SEC_PAIR_WEP40 = 0x00000001
@@ -145,7 +145,7 @@ class NM80211ApSecurityFlags:
 class NM80211ApFlags:
     '''Device flags
 
-    As per https://developer.gnome.org/NetworkManager/unstable/spec.html#type-NM_802_11_AP_FLAGS
+    As per https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NM80211ApFlags
     '''
     NM_802_11_AP_FLAGS_NONE = 0x00000000
     NM_802_11_AP_FLAGS_PRIVACY = 0x00000001
@@ -279,6 +279,7 @@ def SetDeviceActive(self, device_path, active_connection_path):
     dev_obj.Set(DEVICE_IFACE, 'ActiveConnection', dbus.ObjectPath(active_connection_path))
     old_state = dev_obj.Get(DEVICE_IFACE, 'State')
     dev_obj.Set(DEVICE_IFACE, 'State', dbus.UInt32(DeviceState.ACTIVATED))
+    dev_obj.Set(DEVICE_IFACE, 'StateReason', (dbus.UInt32(DeviceState.ACTIVATED), dbus.UInt32(0)))
 
     dev_obj.EmitSignal(DEVICE_IFACE, 'StateChanged', 'uuu', [dbus.UInt32(DeviceState.ACTIVATED), old_state, dbus.UInt32(1)])
 
@@ -290,6 +291,7 @@ def SetDeviceDisconnected(self, device_path):
     dev_obj.Set(DEVICE_IFACE, 'ActiveConnection', dbus.ObjectPath('/'))
     old_state = dev_obj.Get(DEVICE_IFACE, 'State')
     dev_obj.Set(DEVICE_IFACE, 'State', dbus.UInt32(DeviceState.DISCONNECTED))
+    dev_obj.Set(DEVICE_IFACE, 'StateReason', (dbus.UInt32(DeviceState.DISCONNECTED), dbus.UInt32(0)))
 
     dev_obj.EmitSignal(DEVICE_IFACE, 'StateChanged', 'uuu', [dbus.UInt32(DeviceState.DISCONNECTED), old_state, dbus.UInt32(1)])
 
@@ -303,7 +305,7 @@ def AddEthernetDevice(self, device_name, iface_name, state):
     state. You can use the predefined DeviceState values (e. g.
     DeviceState.ACTIVATED) or supply a numeric value. For valid state values
     please visit
-    http://projects.gnome.org/NetworkManager/developers/api/09/spec.html#type-NM_DEVICE_STATE
+    https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMDeviceState
 
     Please note that this does not set any global properties.
 
@@ -321,6 +323,7 @@ def AddEthernetDevice(self, device_name, iface_name, state):
 
     props = {'DeviceType': dbus.UInt32(1),
              'State': dbus.UInt32(state),
+             'StateReason': (dbus.UInt32(state), dbus.UInt32(0)),
              'Interface': iface_name,
              'ActiveConnection': dbus.ObjectPath('/'),
              'AvailableConnections': dbus.Array([], signature='o'),
@@ -352,7 +355,7 @@ def AddWiFiDevice(self, device_name, iface_name, state):
     state. You can use the predefined DeviceState values (e. g.
     DeviceState.ACTIVATED) or supply a numeric value. For valid state values,
     please visit
-    http://projects.gnome.org/NetworkManager/developers/api/09/spec.html#type-NM_DEVICE_STATE
+    https://developer.gnome.org/NetworkManager/unstable/nm-dbus-types.html#NMDeviceState
 
     Please note that this does not set any global properties.
 
@@ -389,6 +392,7 @@ def AddWiFiDevice(self, device_name, iface_name, state):
                               'Driver': 'dbusmock',
                               'DeviceType': dbus.UInt32(2),
                               'State': dbus.UInt32(state),
+                              'StateReason': (dbus.UInt32(state), dbus.UInt32(0)),
                               'Interface': iface_name,
                               'IpInterface': iface_name,
                           })
@@ -413,7 +417,7 @@ def AddAccessPoint(self, dev_path, ap_name, ssid, hw_address,
     You have to specify WiFi Device path, Access Point object name,
     ssid, hw_address, mode, frequency, rate, strength and security.
     For valid access point property values, please visit
-    http://projects.gnome.org/NetworkManager/developers/api/09/spec.html#org.freedesktop.NetworkManager.AccessPoint
+    https://developer.gnome.org/NetworkManager/unstable/gdbus-org.freedesktop.NetworkManager.AccessPoint.html
 
     Please note that this does not set any global properties.
 
@@ -575,6 +579,7 @@ def AddActiveConnection(self, devices, connection_device, specific_object, name,
     settings = conn_obj.settings
     conn_uuid = settings['connection']['uuid']
     conn_type = settings['connection']['type']
+    conn_id = settings['connection']['id']
 
     device_objects = [dbus.ObjectPath(dev) for dev in devices]
 
@@ -592,6 +597,7 @@ def AddActiveConnection(self, devices, connection_device, specific_object, name,
                        'SpecificObject': dbus.ObjectPath(specific_object),
                        'Uuid': conn_uuid,
                        'State': dbus.UInt32(state),
+                       'Id': conn_id,
                    },
                    [])
 
@@ -699,8 +705,7 @@ def SettingsAddConnection(self, connection_settings):
     '''Add a connection.
 
     connection_settings is a String String Variant Map Map. See
-    https://developer.gnome.org/NetworkManager/0.9/spec.html
-        #type-String_String_Variant_Map_Map
+    https://developer.gnome.org/NetworkManager/0.9/spec.html #type-String_String_Variant_Map_Map
 
     If you omit uuid, this method adds one for you.
     '''
@@ -780,8 +785,7 @@ def ConnectionUpdate(self, settings):
     '''Update settings on a connection.
 
     settings is a String String Variant Map Map. See
-    https://developer.gnome.org/NetworkManager/0.9/spec.html
-        #type-String_String_Variant_Map_Map
+    https://developer.gnome.org/NetworkManager/0.9/spec.html#type-String_String_Variant_Map_Map
     '''
     connection_path = self.connection_path
 
